/* cache.h -  */

#ifndef CACHE_H
#define CACHE_H

#include "lib.h"
#include "transfer.h"

extern uint32 share_cache_divider;

#ifdef __cplusplus
extern "C" {
#endif

  void cache_snapshot();
  int cache_time_for_update();
  int cache_lock();
  void cache_unlock();
  void cache_timestamp();
  int cache_shrink(float64 desired_fre);
  int rescan_cache();
  int cache_print(void * data, void * user_data);
  void print_share(void);
  int cfl_callback(gnut_transfer *gt);
  void cache_fixlock(void);

#ifdef __cplusplus
}
#endif

#endif
